Struct playdate_rs_sys::LCDColor
source · #[repr(transparent)]pub struct LCDColor(_);Implementations
sourceimpl LCDColor
impl LCDColor
sourcepub fn as_solid_color(&self) -> Option<LCDSolidColor>
pub fn as_solid_color(&self) -> Option<LCDSolidColor>
Convert the LCDColor to a LCDSolidColor
sourcepub unsafe fn as_pattern(&self) -> Option<LCDPattern>
pub unsafe fn as_pattern(&self) -> Option<LCDPattern>
Convert the LCDColor to a LCDPattern
Safety
This function is unsafe because it casts the LCDColor into a raw pointer and dereferences it. The caller must ensure that the pointer is valid before calling this method.